flameDirectoryPath top-level property

String flameDirectoryPath
final

The directory inside the project, relative to the project directory, that flame run keeps its files in.

Implementation

final flameDirectoryPath = p.join('.dart_tool', 'flame');