vmServiceUriFilePath top-level property

String vmServiceUriFilePath
final

The path, relative to the project directory, of the file that flame run writes the Dart VM Service URI of the running game to.

Implementation

final vmServiceUriFilePath = p.join(flameDirectoryPath, vmServiceUriFileName);